@@ -67,7 +67,8 @@ for my $nsp (qw(lsmb_legacy Form GL AA IS IR OE RP JC PE IC AM BP CP PE User)) {
     }   
 }
 package lsmb_legacy;
-use lib '.';
+use FindBin;
+use lib $FindBin::Bin;
 use Digest::MD5;
 use Try::Tiny;
 use LedgerSMB::App_State;
